package com.example.assignment1;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import androidx.appcompat.app.AppCompatActivity;

public class MainActivity extends AppCompatActivity {

    protected CounterButtonSharedPreferenceHelper counterButtonSharedPrefHelper;

    protected TextView counter;

    protected CountSharedPreferenceHelper countSharedPreferenceHelper;

    protected Button settingsButton;

    protected Button showCountsButton;

    protected Button firstCounterButton;
    protected Button secondCounterButton;
    protected Button thirdCounterButton;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // initialization
        settingsButton = findViewById(R.id.settings_button);
        showCountsButton = findViewById(R.id.show_counts_button);

        firstCounterButton = findViewById(R.id.FirstEventButton);
        secondCounterButton = findViewById(R.id.SecondEventButton);
        thirdCounterButton = findViewById(R.id.ThirdEventButton);

        counter = findViewById(R.id.counter);

        counterButtonSharedPrefHelper = new CounterButtonSharedPreferenceHelper(MainActivity.this);
        countSharedPreferenceHelper = new CountSharedPreferenceHelper(MainActivity.this);

        settingsButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // Create an Intent to start the SettingsActivity
                goToSettingsActivity();
            }
        });

        showCountsButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // Create an Intent to start the DataActivity
                goToDataActivity();
            }
        });

        firstCounterButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                incrementCounter("1");
            }
        });

        secondCounterButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                incrementCounter("2");
            }
        });

        thirdCounterButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                incrementCounter("3");
            }
        });
    }

    @Override
    protected void onStart() {
        super.onStart();

        // go to settings activity in edit mode
        if (counterButtonSharedPrefHelper.getCounterButtonName(CounterButtonNames.FIRST).trim().isEmpty() ||
                counterButtonSharedPrefHelper.getCounterButtonName(CounterButtonNames.SECOND).trim().isEmpty() ||
                counterButtonSharedPrefHelper.getCounterButtonName(CounterButtonNames.THIRD).trim().isEmpty()) {
            Toast.makeText(getApplicationContext(), "Event Button(s) can not be empty", Toast.LENGTH_SHORT).show();
            goToSettingsActivity();

        // everything field is good, no edit needed
        } else {
            firstCounterButton.setText(counterButtonSharedPrefHelper.getCounterButtonName(CounterButtonNames.FIRST));
            secondCounterButton.setText(counterButtonSharedPrefHelper.getCounterButtonName(CounterButtonNames.SECOND));
            thirdCounterButton.setText(counterButtonSharedPrefHelper.getCounterButtonName(CounterButtonNames.THIRD));
            counter.setText(String.format(Integer.toString(countSharedPreferenceHelper.getCurrentCount())));
        }

    }

    private void goToSettingsActivity() {
        Intent intent = new Intent(MainActivity.this, SettingsActivity.class);
        startActivity(intent);
    }

    private void goToDataActivity() {
        Intent intent = new Intent(MainActivity.this, dataActivity.class);
        startActivity(intent);
    }

    private void incrementCounter(String counterNumber) {
        try {
            if (Integer.parseInt(counter.getText().toString()) < countSharedPreferenceHelper.getMaxCount()) {
                // add the event into the events list
                // the events list is just one string with number 1, 2, 3 in it
                // i.e "123112233331231231122332"
                countSharedPreferenceHelper.setEventsList(countSharedPreferenceHelper.getEventsList() + counterNumber);

                // update the counter
                String currentValue = counter.getText().toString();
                int intValue = Integer.parseInt(currentValue);
                int newValue = intValue + 1;
                counter.setText(String.valueOf(newValue));
            } else {
                Toast.makeText(getApplicationContext(), "Maximum count has been reached", Toast.LENGTH_SHORT).show();
            }
        } catch (NumberFormatException e) {
            Toast.makeText(getApplicationContext(), "Error incrementing the counter", Toast.LENGTH_SHORT).show();
        }
    }
}